==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/NativeUIContent.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { NativeUIContainer } from "./NativeUIContainer";
import { markType } from "./type";
/**
 * @hidden
 */
var NativeUIContent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NativeUIContent, _super);
    function NativeUIContent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NativeUIContent.prototype.get_e = function () {
        return 0;
    };
    Object.defineProperty(NativeUIContent.prototype, "bn", {
        get: function () {
            return this.d;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIContent.prototype, "bo", {
        get: function () {
            return this.bn.getContent(this.ak);
        },
        set: function (a) {
            this.bn.setContent(this.ak, a);
        },
        enumerable: false,
        configurable: true
    });
    NativeUIContent.$t = markType(NativeUIContent, 'NativeUIContent', NativeUIContainer.$);
    return NativeUIContent;
}(NativeUIContainer));
export { NativeUIContent };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/NativeUIContent.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { NativeUIContainer } from "./NativeUIContainer";
import { markType } from "./type";
/**
 * @hidden
 */
var NativeUIContent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NativeUIContent, _super);
    function NativeUIContent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NativeUIContent.prototype.get_e = function () {
        return 0;
    };
    Object.defineProperty(NativeUIContent.prototype, "bp", {
        get: function () {
            return this.d;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIContent.prototype, "bq", {
        get: function () {
            return this.bp.getContent(this.am);
        },
        set: function (a) {
            this.bp.setContent(this.am, a);
        },
        enumerable: false,
        configurable: true
    });
    NativeUIContent.$t = markType(NativeUIContent, 'NativeUIContent', NativeUIContainer.$);
    return NativeUIContent;
}(NativeUIContainer));
export { NativeUIContent };
